<?php 
    // continue the session
    session_start();
    
    // Add includes to PHP files that I will need to access
    include 'php_only_scripts/database.php';
    include 'php_only_scripts/presentation.php';
    include 'php_only_scripts/machine_presentation.php';

    // Init some variables
    $userRow=null;

    // Assume NOT gtg
    $gtg = false;

    // Create and Setup the database
    $db = new Database();
    $db->setupTmsDB();

    // Attempt to log in with this user
    $currentUser = $db->getLoggedInSessionUser(session_id());
            
    // If there is only one result for a username/password combo, then they are good to go.
    if ($currentUser == null){
        exit;
    }
    elseif (mysqli_num_rows($currentUser)==1){
        // Attempt to get the user row
        $userRow = $currentUser->fetch_assoc();
        
        // Determine if this user has access to this page
        if ($userRow["UserLevel"]=='TIMECARD ONLY' || 
            $userRow["SUEmployee"]!=1 ||
            $userRow["AccountStatus"]!='ACTIVE'){
            // redirect to the invalid access page
            echo ('<script>window.location = "invalid_access.php";</script>');

            exit;
        }
        
        // Set the good to go until they log out
        $gtg = true;
        
        // Determine if BOTH the user name AND password has been set
        if (isset($_POST['formSubmitted']) && 
            htmlspecialchars($_POST['formSubmitted'])=='TRUE'){
            // Determine if this user can even modify
            if ($userRow["CanModify"]==0){
                // redirect to the companies page
                echo ('<script>window.location = "machines.php";</script>');
            }
            else {
                // Set the local variables from what was posted
                $name = htmlspecialchars($_POST['name'], ENT_QUOTES, 'UTF-8');
                $type = htmlspecialchars($_POST['type'], ENT_QUOTES, 'UTF-8');
                $description = htmlspecialchars($_POST['description'], ENT_QUOTES, 'UTF-8');
                $xTravel = htmlspecialchars($_POST['xTravel'], ENT_QUOTES, 'UTF-8');
                $yTravel = htmlspecialchars($_POST['yTravel'], ENT_QUOTES, 'UTF-8');
                $zTravel = htmlspecialchars($_POST['zTravel'], ENT_QUOTES, 'UTF-8');
                $dateAcquired = htmlspecialchars($_POST['dateAcquired'], ENT_QUOTES, 'UTF-8');
                $maxRPM = htmlspecialchars($_POST['maxRPM'], ENT_QUOTES, 'UTF-8');
                $airBlast=(isset($_POST['airBlast'])?1:0);
                $showOnWhiteboard=(isset($_POST['showOnWhiteboard'])?1:0);
                $maxTools = htmlspecialchars($_POST['maxTools'], ENT_QUOTES, 'UTF-8');
                $isDown=(isset($_POST['isDown'])?1:0);

                // Let's create the insert query off of what we have
                $sql='INSERT INTO machines (';
                if ($name!=null) {$sql = $sql . 'Name';}
                if ($type!=null) {$sql = $sql . ', Type';}
                if ($description!=null) {$sql = $sql . ', Description';}
                if ($xTravel!=null) {$sql = $sql . ', XTravel';}
                if ($yTravel!=null) {$sql = $sql . ', YTravel';}
                if ($zTravel!=null) {$sql = $sql . ', ZTravel';}
                if ($dateAcquired!=null) {$sql = $sql . ', DateAcquired';}
                if ($maxRPM!=null) {$sql = $sql . ', MaxRPM';}
                $sql = $sql . ', AirBlast';
                $sql = $sql . ', ShowOnWhiteboard';
                if ($maxTools!=null) {$sql = $sql . ', MaxTools';}
                $sql = $sql . ', IsDown';
                $sql=$sql .') VALUES (';
                if ($name!=null) {$sql = $sql  . '"' .$name . '"';}
                if ($type!=null) {$sql = $sql . ', "' .$type . '"';}
                if ($description!=null) {$sql = $sql . ', "' .$description . '"';}
                if ($xTravel!=null) {$sql = $sql . ', ' .$xTravel . '';}
                if ($yTravel!=null) {$sql = $sql . ', ' .$yTravel . '';}
                if ($zTravel!=null) {$sql = $sql . ', ' .$zTravel . '';}
                if ($dateAcquired!=null) {$sql = $sql . ', "' .$dateAcquired . '"';}
                if ($maxRPM!=null) {$sql = $sql . ', ' .$maxRPM . '';}
                $sql = $sql . ', ' . $airBlast;
                $sql = $sql . ', ' . $showOnWhiteboard;
                if ($maxTools!=null) {$sql = $sql . ', ' .$maxTools . '';}
                $sql = $sql . ', ' . $isDown;
                $sql=$sql .');';

                // Attempt to run the query and evaluate the response
                if ($db->queryDB($sql, $userRow, "addMachine Form occurance 1")){
                    // Get the most recent ID (machine)
                    $newMachineID = mysqli_insert_id($db->getDBConnection());

                    // Determine if we have tools to add
                    if ($maxTools!=null) {
                        // Reinit the sql string
                        $sql = '';
                        
                        // Loop through the max tool amount and add a row for each tool
                        for ($toolNumber = 1; $toolNumber < ($maxTools+1); $toolNumber++) {
                            // Insert a row with only the new tool number and Machin id into assigned tools
                            $sql='INSERT INTO assignedtools (MachineID, Position) ' .
                                 'VALUES (' . $newMachineID . ', ' . $toolNumber . ');';
                            
                            // Attempt to run the query and evaluate the response
                            $db->queryDB($sql, $userRow, "addMachine Form occurance 2");
                        }
                    }
                    
                    // redirect to the machines page
                    echo ('<script>window.location = "machines.php";</script>');
                }
                else {
                    echo '<script>alert("Machine was NOT added to the database. Please check the data and try again.");</script>';
                    // TODO: How do I want to display a failure to the user?
                    // echo '<font color="red">Task was NOT added to the database. <br> Please check the data and try again.</font>';
                }

                // Change the form back to NOT being submitted
                $_SESSION['formSubmitted']='FALSE';
            }
        }
        else {
            // Set the form submitted session variable to FALSE
            $_POST['formSubmitted']='FALSE';
        }
    }
?>
        
﻿<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

    <title>Task Management System - Add Machine</title>

    <meta name="keywords" content="GIS,data,testing,IT" />
    <meta name="description" content="EES Divisions." />

    <script src="./SpryAssets/SpryMenuBar.js" type="text/javascript"></script>
    <script src="./javascript/addresses.js" type="text/javascript"></script>
    <script src="scripts/jpicker-1.1.6/jquery-1.4.4.min.js" type="text/javascript"></script>
    <script src="scripts/jpicker-1.1.6/jpicker-1.1.6.min.js" type="text/javascript"></script>
    <script language="JavaScript" src="scripts/gen_validatorv4.js" type="text/javascript"></script>
    
    <link rel="icon" href="images/ees_ico.ico"/> 
    
    <link href="scripts/jpicker-1.1.6/css/jPicker-1.1.6.css" rel="stylesheet" type="text/css"/>
    <link href="./SpryAssets/SpryMenuBarHorizontal.css" rel="stylesheet" type="text/css" />
    <link href="./SpryAssets/SpryMenuBarVertical.css" rel="stylesheet" type="text/css" />
    <link rel = "stylesheet" type="text/css" href="./css/contentpage.css" >

    <script type="text/javascript">
      $(function()
        {
          $.fn.jPicker.defaults.images.clientPath='scripts/jpicker-1.1.6/images/';
        });
    </script>
        
    <style type="text/css">
        .Table
        {
            display: table;
            border: solid red;
            border-width: 3px;
            border-bottom: thick solid red;
            width: 100%;
        }
        .Title
        {
            display: table-caption;
            text-align: center;
            font-weight: bold;
            font-size: larger;
        }
        .Heading
        {
            display: table-row;
            font-weight: bold;
            text-align: center;
            width: 100%;
        }
        .Row
        {
            display: table-row;
            width: 100%;
            position:relative;
        }
        .cell
        {
            display: table-cell;
            position:absolute; 
            top:50%; 
            height:10em; 
            margin-top:-5em;
            padding-left: 4px;
            padding-right: 4px;
            font-weight: bold;
            font-size: 10;
        }
        .fullLabelCell
        {
            width: 20%;
            text-align: center;
        }
        .fullTextCell
        {
            width: 80%;
            text-align: center;
        }
        .thirdLabelCell
        {
            width: 8%;
            text-align: center;
        }
        .thirdTextCell
        {
            width: 25%;
            text-align: center;
        }
        .addressButtonsCell
        {
            vertical-align: middle;
            text-align: center;
        }
        span {
          display: inline-block;
          vertical-align: middle;
          line-height: normal;      
        }
    </style>
</head>

<body class="thrColElsHdr">

<div id="container">
  
<!-- start of banner wrap --->

<div id="topContent">
  
<div>
   <div class="MenuBarHorizontal" id="navBar">  <ul id="TopNav" class="MenuBarHorizontal">

    <script type="text/javascript">
    <!--
    var MenuBar2 = new Spry.Widget.MenuBar("TopNav", {imgDown:"./SpryAssets/SpryMenuBarDownHover.gif", imgRight:"./SpryAssets/SpryMenuBarRightHover.gif"});
    //-->
    </script>

    </div>
  </div>
</div>
<!-- end of banner wrap --->

  <!-- end #header -->
  <br class="clearfloat" />
  <div id="sidebar1">
      <?php 
        // Determine if we are GTG
        if ($gtg){
          // Render the appropriate presentation for the tasks sidebar
          getSidebar($userRow, 'equipment');
        }
      ?>       
      <br class="clearfloat" />
  <!-- end #sidebar1 -->
  </div>
  
  <!-- start #mainContent -->
  <div id="mainContent">
    <div class="maintitle">Task Management System - Add Machine</div>
    <div class="breadcrumb"> <a href="../index.html"> Home </a> > <a href="companies.php"> Task Management System </a> > <a href="addMachine.php"> Add Machine </a></div>

    <br>
    <?php
        // Determine if they are GTG
        if ($gtg){
            echo getMachine($db, $userRow, null);
        }
        else {
            // Set the login failed to true
            $_SESSION['failedLogin']='TRUE';

            // Add a session variable that is this page URL
            $_SESSION['pageToGoTo']=$_SERVER['REQUEST_URI'];

            // redirect to the login page
            echo ('<script>window.location = ".";</script>');
        }
    ?>       
    
  <!-- end #mainContent -->
  
  <!-- This clearing element should immediately follow the #mainContent div in order to force the #container div to contain all child floats -->
  <br class="clearfloat" />
  
  <!-- start #footer --></div>
   <div id="footer">
    <p>© 2018 Evolve Engineering and Software. EES, Evolve Engineering and Software, EES Logo are registered marks of Evolve Engineering and Software.</p>
  <!-- end #footer -->
   </div>
<!-- end #container -->
</div>

</body>

</html>