<?php 
    // continue the session
    session_start();

    // Add includes to PHP files that I will need to access
    include 'php_only_scripts/database.php';
    include 'php_only_scripts/presentation.php';
    include 'php_only_scripts/stocklist_presentation.php';

    // Init some variables
    $userRow=null;
    $currentCategory=-1;
    $currentMaterialID=-1;
    $searchPhrase="";
    $sort=1;

    // Assume NOT gtg
    $gtg = false;

    // Create and Setup the database
    $db = new Database();
    $db->setupTmsDB();

    // Attempt to log in with this user
    $currentUser = $db->getLoggedInSessionUser(session_id());
    
    // If there is only one result for a username/password combo, then they are good to go.
    if ($currentUser == null){
        exit;
    }
    elseif (mysqli_num_rows($currentUser)==1){
        // Attempt to get the user row
        $userRow = $currentUser->fetch_assoc();

        // Determine if this user has access to this page
        if ($userRow["UserLevel"]=='TIMECARD ONLY' || 
            $userRow["SUEmployee"]!=1 ||
            $userRow["AccountStatus"]!='ACTIVE'){
            // redirect to the invalid access page
            echo ('<script>window.location = "invalid_access.php";</script>');

            exit;
        }
        
        // Set the good to go until they log out
        $gtg = true;
        
        // Determine if the category combo box changed
        if (isset($_GET['c'])){
            // Set the session variable to the new value of the combo box
            $currentCategory = rawurldecode($_GET['c']);
        }

        // Determine if the material ID combo box changed
        if (isset($_GET['mid'])){
            // Set the session variable to the new value of the combo box
            $currentMaterialID = rawurldecode($_GET['mid']);
        }
        
        // Determine if there is a search phrase
        if (isset($_GET['sp'])){
            // Set the search phrase
            $searchPhrase=rawurldecode($_GET['sp']);
        }

        // Determine if there is a sort preference
        if (isset($_GET['sn']) ){
            // Hold onto the sort info
            $sort = rawurldecode($_GET['sn']);
        }
    }
?>
﻿<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

    <title>Task Management System - Materials Stocked</title>

    <meta name="keywords" content="GIS,data,testing,IT" />
    <meta name="description" content="EES Divisions." />

    <script src="./SpryAssets/SpryMenuBar.js" type="text/javascript"></script>

    <link rel="icon" href="images/ees_ico.ico"/> 
    <link href="./SpryAssets/SpryMenuBarHorizontal.css" rel="stylesheet" type="text/css" />
    <link href="./SpryAssets/SpryMenuBarVertical.css" rel="stylesheet" type="text/css" />
    <link rel = "stylesheet" type="text/css" href="./css/contentpage.css" >
        
    <style type="text/css">
        .Table
        {
            display: table;
            width: 100%;
        }
        .Title
        {
            display: table-caption;
            text-align: center;
            font-weight: bold;
            font-size: larger;
            width: 100%;
        }
        .Heading
        {
            display: table-row;
            font-weight: bold;
            text-align: center;
            width: 100%;
        }
        .Row
        {
            display: table-row;
            width: 100%;
        }
        .cell
        {
            display: table-cell;
            border: solid;
            border-width: thin;
            padding-left: 2px;
            padding-right: 2px;
            font-weight: bold;
            font-size: 14;
        }
        .catCell
        {
            width: 12%;
            text-align: center;
        }
        .nameCell
        {
            text-align: center;
        }
        .locationCell
        {
            width: 15%;
            text-align: center;
        }
        .typeCell
        {
            width: 10%;
            text-align: center;
        }
        .amountCell
        {
            width: 10%;
            text-align: center;
        }
        .llCell
        {
            width: 8%;
            text-align: center;
        }
        .updateCell
        {
            width: 10%;
            text-align: center;
        }
        .alertBackground {
            background:repeating-linear-gradient(
                25deg,
                rgba(204, 0, 0, .5),
                rgba(204, 0, 0, .5) 10px,
                rgba(77, 77, 77, .5) 10px,
                rgba(77, 77, 77, .5) 20px
            );
        }
        span {
          display: inline-block;
          vertical-align: middle;
          line-height: normal;      
        }
    </style>
    <script type="text/javascript">
        function CreateURLSearchVariables() {
            // Get all of the variables
            var category = document.getElementById('category').value===null?'&c=-1':'&c=' + encodeURIComponent(document.getElementById('category').value);
            var sortNumber = document.getElementById('sortNumber').value===null?'&sn=1':'&sn='+encodeURIComponent(document.getElementById('sortNumber').value);
            var materialID = document.getElementById('materialID').value===null?'&mid=-1':'&mid='+encodeURIComponent(document.getElementById('materialID').value);
            var searchPhrase = document.getElementById('searchPhrase').value===''?'':'&sp=' + encodeURIComponent(document.getElementById('searchPhrase').value);
        
            // Return what we can build up
            return '\?' + category + sortNumber + materialID + searchPhrase;
        }
        
        function CreateAndGotoSearchOptions() {
            // Get the base location
            var goToLocation = window.location.href.split('?')[0];

            // Build the location to go to with get variables
            goToLocation = goToLocation + CreateURLSearchVariables();
            
            // Go to the location built
            window.location=goToLocation;
        }
    </script>    
        
</head>

<body class="thrColElsHdr">

<div id="container">
  
<!-- start of banner wrap --->

<div id="topContent">
  
<div>
  </div>
</div>
<!-- end of banner wrap --->

  <!-- end #header -->
  <br class="clearfloat" />
  <div id="sidebar1">
      <?php 
        // Determine if we are GTG
        if ($gtg){
          // Render the appropriate presentation for the tasks sidebar
          getSidebar($userRow, 'equipment');
        }
      ?>       
      <br class="clearfloat" />
  <!-- end #sidebar1 -->
  </div>
  
  <!-- start #mainContent -->
  <div id="mainContent">
    <div class="maintitle">Task Management System - Materials Stocked</div>
    <div class="breadcrumb"> <a href="../index.html"> Home </a> > <a href="tasks.php"> Task Management System </a> > <a href="stockedMaterials.php"> Materials Stocked </a></div>

    <br>
        
    <?php
        // Determine if they are GTG
        if ($gtg){
            // Time to query for materials
            echo(retrieveStockedMaterialsAsList($db, $userRow, $currentCategory, $sort, $currentMaterialID, $searchPhrase));
        }
        else {
            // Set the login failed to true
            $_SESSION['failedLogin']='TRUE';

            // Add a session variable that is this page URL
            $_SESSION['pageToGoTo']=$_SERVER['REQUEST_URI'];

            // redirect to the login page
            echo ('<script>window.location = ".";</script>');
        }
    ?>       

  <!-- end #mainContent -->
  
  <!-- This clearing element should immediately follow the #mainContent div in order to force the #container div to contain all child floats -->
  <br class="clearfloat" />
  
  <!-- start #footer --></div>
   <div id="footer">
    <p>© 2018 Evolve Engineering and Software. EES, Evolve Engineering and Software, EES Logo are registered marks of Evolve Engineering and Software.</p>
  <!-- end #footer -->
   </div>
<!-- end #container -->
</div>

</body>

</html>